@@ -1,9 +1,12 @@
 #-*- coding: utf-8 -*-
-import os, sys
+import os, sys,logging
 class Git():
 	cmd = []
 	def __init__(self, workspace = None, logger = None):
-		self.logger = logger
+		if logger :
+			self.logger = logger
+		else:
+			self.logger = logging.getLogger()
 		self.workspace = os.path.expanduser(workspace)
 		if os.path.exists(self.workspace) :
 			os.chdir(self.workspace)
@@ -18,9 +21,9 @@ class Git():
 			self.opt = opt
 	def clone(self, uri, project = None):
 		if project :
-			self.cmd.append('clone '+ uri +' '+ project)
+			self.cmd.append('clone '+ self.opt +' '+ uri +' '+ project)
 		else:
-			self.cmd.append('clone '+ uri)
+			self.cmd.append('clone '+ self.opt +' '+ uri)
 		return(self)
 	def clean(self, param=''):
 		#git clean -df
@@ -36,6 +39,9 @@ class Git():
 	def commit(self, msg = '', param=''):
 		self.cmd.append('commit '+param+' -m "'+msg+'"')
 		return(self)
+	def checkout(self, branch):
+		self.cmd.append('checkout {0}'.format(branch))
+		return(self)
 	def status(self):
 		self.cmd.append('status')
 		return(self)
@@ -47,6 +53,9 @@ class Git():
 			# os.chdir(self.workspace)
 		self.cmd.append('pull --progress')
 		return(self)
+	def fetch(self):
+		self.cmd.append('fetch')
+		return(self)	
 	def push(self):
 		self.cmd.append('push --progress')
 		return(self)
@@ -72,7 +81,9 @@ class Git():
 		os.chdir(self.workspace)
 		self.cmd.append('tag ' + tagname)
 		return(self)
-	
+	def reset(self):
+		self.cmd.append('reset HEAD .')
+		return(self)
 	def command(self, cmd, argument):
 		self.cmd.append('%s %s' %(cmd, argument))
 	def debug(self):
@@ -87,9 +98,11 @@ class Git():
 			self.logger.debug('git '+ line)
 			self.logger.debug(rev)
 			if rev == 256 :
-				exit(0)
+				return rev
+			print("-")
 		self.cmd = []
-		print("-")
+		
+		return 0
 
 class GitBranch(Git):
 	def __init__(self,workspace = None, logger = None):
